==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_ldap/l10n/lv.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "Neizdevās nodzēstu samērošanu.",
    "Failed to delete the server configuration" : "Neizdevās izdzēst servera konfigurāciju",
    "No action specified" : "Nav norādīta darbība",
    "No configuration specified" : "Nav norādīta konfigurācija",
    "No data specified" : "Nav norādīti dati",
    " Could not set configuration %s" : "Nevarēja iestatīt konfigurāciju %s",
    "Action does not exist" : "Darbība neeksistē",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "The Base DN appears to be wrong" : "DN bāze šķiet nepareiza",
    "Testing configuration…" : "Konfigurācijas pārbaude...",
    "Configuration incorrect" : "Nepareiza konfigurācija",
    "Configuration incomplete" : "Nepilnīga konfigurācija",
    "Configuration OK" : "Konfigurācija OK",
    "Select groups" : "Izvēlieties grupas",
    "Select object classes" : "Atlasiet objektu klases",
    "Please check the credentials, they seem to be wrong." : "Lūdzu, pārbaudiet akreditācijas datus, tie šķiet nepareizi.",
    "Please specify the port, it could not be auto-detected." : "Lūdzu, norādiet portu, tas nevarēja būt noteikts automātiski.",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "DN bāzi nevarēja noteikt, lūdzu, pārskatiet datus, resursdatoru un portu.",
    "Could not detect Base DN, please enter it manually." : "Nevarēja noteikt DN bāzi, lūdzu, ievadiet to manuāli.",
    "{nthServer}. Server" : "{nthServer}. Serveris",
    "No object found in the given Base DN. Please revise." : "Neviens objekts nav atrasts konkrētā DN bāzē. Lūdzu pārskatīt.",
    "More than 1,000 directory entries available." : "Vairāk nekā 1,000 kataloga ieraksti ir pieejami.",
    "An error occurred. Please check the Base DN, as well as connection settings and credentials." : "Radās kļūda. Lūdzu, pārbaudiet bāzes DN, kā arī savienojuma iestatījumus vai akreditācijas datus.",
    "Do you really want to delete the current Server Configuration?" : "Vai tiešām vēlaties dzēst pašreizējo servera konfigurāciju?",
    "Confirm Deletion" : "Apstiprināt dzēšanu",
    "Mappings cleared successfully!" : "Kartējumi notīrīta veiksmīgi!",
    "Error while clearing the mappings." : "Kļūda, dzēšot kartējumus.",
    "LDAP Operations error. Anonymous bind might not be allowed." : "LDAP operācijas kļūda. Anonīma sasaiste, iespējams, nav atļauta.",
    "Select attributes" : "Atlasīt atribūtus",
    "Password change rejected. Hint: " : "Paroles maiņas noraidīja. Padoms:",
    "LDAP / AD integration" : "LDAP / AD integrācija",
    "_%s group found_::_%s groups found_" : ["%s grupas atrastas","%s grupas atrastas","%s grupas atrastas"],
    "_%s user found_::_%s users found_" : ["%s lietotāji atrasti","%s lietotāji atrasti","%s lietotāji atrasti"],
    "Invalid Host" : "Nederīgs resursdators",
    "Test Configuration" : "Testa konfigurācija",
    "Help" : "Palīdzība",
    "Only these object classes:" : "Tikai šo objektu kategorijas:",
    "Only from these groups:" : "Tikai no šīm grupām:",
    "Search groups" : "Meklēt grupas",
    "Available groups" : "Pieejamās grupas",
    "Selected groups" : "Izvēlētās grupas",
    "Edit LDAP Query" : "Labot LDAP vaicājumu",
    "LDAP Filter:" : "LDAP filtrs:",
    "LDAP / AD Username:" : "LDAP / AD lietotājvārds:",
    "LDAP / AD Email Address:" : "LDAP / AD e-pasta adrese:",
    "Other Attributes:" : "Citi atribūti:",
    "Test Loginname" : "Pārbaudiet lietotājvārdu",
    "Verify settings" : "Pārbaudīt iestatījumus",
    "%s. Server:" : "%s. Serveris:",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Detect Port" : "Noteikt portu",
    "User DN" : "Lietotāja DN",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "Klienta lietotāja DN, ar ko veiks sasaisti, piemēram, uid=agent,dc=example,dc=com. Lai piekļūtu anonīmi, atstājiet DN un paroli tukšu.",
    "Password" : "Parole",
    "For anonymous access, leave DN and Password empty." : "Lai piekļūtu anonīmi, atstājiet DN un paroli tukšu.",
    "One Base DN per line" : "Viena bāzes DN rindā",
    "You can specify Base DN for users and groups in the Advanced tab" : "Lietotājiem un grupām var norādīt bāzes DN  cilnē “Paplašināti”",
    "Detect Base DN" : "Noteikt bāzes DN",
    "Test Base DN" : "Testēt bāzes DN",
    "Saving" : "Saglabā",
    "Back" : "Atpakaļ",
    "Continue" : "Turpināt",
    "An internal error occurred." : "Radās iekšēja kļūda.",
    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Wrong password." : "Nepareiza parole.",
    "Cancel" : "Atcelt",
    "Server" : "Serveris",
    "Users" : "Lietotāji",
    "Login Attributes" : "Pieteikšanās atribūti",
    "Groups" : "Grupas",
    "Expert" : "Eksperts",
    "Advanced" : "Paplašināti",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Brīdinājums:</b> PHP LDAP modulis nav uzinstalēts, aizmugure nedarbosies. Lūdzu, prasiet savam sistēmas administratoram kādu no tām deaktivēt.",
    "Connection Settings" : "Savienojuma iestatījumi",
    "Configuration Active" : "Konfigurācija ir aktīva",
    "When unchecked, this configuration will be skipped." : "Ja nav atzīmēts, šī konfigurācija tiks izlaista.",
    "Backup (Replica) Host" : "Rezerves (kopija) serveris",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "Norādi rezerves serveri (nav obligāti). Tam ir jābūt galvenā LDAP/AD servera kopijai.",
    "Backup (Replica) Port" : "Rezerves (kopijas) ports",
    "Disable Main Server" : "Deaktivēt galveno serveri",
    "Turn off SSL certificate validation." : "Izslēgt SSL sertifikātu validēšanu.",
    "Cache Time-To-Live" : "Kešatmiņas dzīvlaiks",
    "in seconds. A change empties the cache." : "sekundēs. Izmaiņas iztukšos kešatmiņu.",
    "Directory Settings" : "Direktorijas iestatījumi",
    "User Display Name Field" : "Lietotāja redzamā vārda lauks",
    "Base User Tree" : "Bāzes lietotāju koks",
    "One User Base DN per line" : "Viens lietotājs bāzes DN rindā",
    "User Search Attributes" : "Lietotāju meklēšanas atribūts",
    "Optional; one attribute per line" : "Neobligāti; viens atribūts rindā",
    "Group Display Name Field" : "Grupas redzamā nosaukuma lauks",
    "Base Group Tree" : "Bāzes grupu koks",
    "One Group Base DN per line" : "Viena grupu bāzes DN rindā",
    "Group Search Attributes" : "Grupu meklēšanas atribūts",
    "Group-Member association" : "Grupu piederības asociācija",
    "Enable LDAP password changes per user" : "Iespējot LDAP paroles maiņu katram lietotājam",
    "(New password is sent as plain text to LDAP)" : "(Jaunā parole tiek nosūtīta kā vienkāršs teksts ar LDAP)",
    "Special Attributes" : "Īpašie atribūti",
    "Quota Field" : "Kvotu lauks",
    "Quota Default" : "Kvotas noklusējums",
    "Email Field" : "E-pasta lauks",
    "User Home Folder Naming Rule" : "Lietotāja mājas mapes nosaukšanas kārtula",
    "Internal Username" : "Iekšējais lietotājvārds",
    "Override UUID detection" : "Ignorēt UUID noteikšanu",
    "UUID Attribute for Users:" : "UUID atribūti lietotājiem:",
    "UUID Attribute for Groups:" : "UUID atribūti grupām:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_ldap/l10n/lv.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "Neizdevās nodzēstu samērošanu.",
    "Failed to delete the server configuration" : "Neizdevās izdzēst servera konfigurāciju",
    "No action specified" : "Nav norādīta darbība",
    "No configuration specified" : "Nav norādīta konfigurācija",
    "No data specified" : "Nav norādīti dati",
    " Could not set configuration %s" : "Nevarēja iestatīt konfigurāciju %s",
    "Action does not exist" : "Darbība neeksistē",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "The Base DN appears to be wrong" : "DN bāze šķiet nepareiza",
    "Testing configuration…" : "Konfigurācijas pārbaude...",
    "Configuration incorrect" : "Nepareiza konfigurācija",
    "Configuration incomplete" : "Nepilnīga konfigurācija",
    "Configuration OK" : "Konfigurācija OK",
    "Select groups" : "Izvēlieties grupas",
    "Select object classes" : "Atlasiet objektu klases",
    "Please check the credentials, they seem to be wrong." : "Lūdzu, pārbaudiet akreditācijas datus, tie šķiet nepareizi.",
    "Please specify the port, it could not be auto-detected." : "Lūdzu, norādiet portu, tas nevarēja būt noteikts automātiski.",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "DN bāzi nevarēja noteikt, lūdzu, pārskatiet datus, resursdatoru un portu.",
    "Could not detect Base DN, please enter it manually." : "Nevarēja noteikt DN bāzi, lūdzu, ievadiet to manuāli.",
    "{nthServer}. Server" : "{nthServer}. Serveris",
    "No object found in the given Base DN. Please revise." : "Neviens objekts nav atrasts konkrētā DN bāzē. Lūdzu pārskatīt.",
    "More than 1,000 directory entries available." : "Vairāk nekā 1,000 kataloga ieraksti ir pieejami.",
    "An error occurred. Please check the Base DN, as well as connection settings and credentials." : "Radās kļūda. Lūdzu, pārbaudiet bāzes DN, kā arī savienojuma iestatījumus vai akreditācijas datus.",
    "Do you really want to delete the current Server Configuration?" : "Vai tiešām vēlaties dzēst pašreizējo servera konfigurāciju?",
    "Confirm Deletion" : "Apstiprināt dzēšanu",
    "Mappings cleared successfully!" : "Kartējumi notīrīta veiksmīgi!",
    "Error while clearing the mappings." : "Kļūda, dzēšot kartējumus.",
    "LDAP Operations error. Anonymous bind might not be allowed." : "LDAP operācijas kļūda. Anonīma sasaiste, iespējams, nav atļauta.",
    "Select attributes" : "Atlasīt atribūtus",
    "Password change rejected. Hint: " : "Paroles maiņas noraidīja. Padoms:",
    "_%s group found_::_%s groups found_" : ["%s grupas atrastas","%s grupas atrastas"],
    "_%s user found_::_%s users found_" : ["%s lietotāji atrasti","%s lietotāji atrasti"],
    "Invalid Host" : "Nederīgs resursdators",
    "Test Configuration" : "Testa konfigurācija",
    "Help" : "Palīdzība",
    "Only these object classes:" : "Tikai šo objektu kategorijas:",
    "Only from these groups:" : "Tikai no šīm grupām:",
    "Search groups" : "Meklēt grupas",
    "Available groups" : "Pieejamās grupas",
    "Selected groups" : "Izvēlētās grupas",
    "Edit LDAP Query" : "Labot LDAP vaicājumu",
    "LDAP Filter:" : "LDAP filtrs:",
    "Other Attributes:" : "Citi atribūti:",
    "Test Loginname" : "Pārbaudiet lietotājvārdu",
    "Verify settings" : "Pārbaudīt iestatījumus",
    "%s. Server:" : "%s. Serveris:",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Detect Port" : "Noteikt portu",
    "User DN" : "Lietotāja DN",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "Klienta lietotāja DN, ar ko veiks sasaisti, piemēram, uid=agent,dc=example,dc=com. Lai piekļūtu anonīmi, atstājiet DN un paroli tukšu.",
    "Password" : "Parole",
    "For anonymous access, leave DN and Password empty." : "Lai piekļūtu anonīmi, atstājiet DN un paroli tukšu.",
    "One Base DN per line" : "Viena bāzes DN rindā",
    "You can specify Base DN for users and groups in the Advanced tab" : "Lietotājiem un grupām var norādīt bāzes DN  cilnē “Paplašināti”",
    "Detect Base DN" : "Noteikt bāzes DN",
    "Test Base DN" : "Testēt bāzes DN",
    "Saving" : "Saglabā",
    "Back" : "Atpakaļ",
    "Continue" : "Turpināt",
    "An internal error occurred." : "Radās iekšēja kļūda.",
    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Wrong password." : "Nepareiza parole.",
    "Cancel" : "Atcelt",
    "Server" : "Serveris",
    "Users" : "Lietotāji",
    "Login Attributes" : "Pieteikšanās atribūti",
    "Groups" : "Grupas",
    "Expert" : "Eksperts",
    "Advanced" : "Paplašināti",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>Brīdinājums:</b> PHP LDAP modulis nav uzinstalēts, aizmugure nedarbosies. Lūdzu, prasiet savam sistēmas administratoram kādu no tām deaktivēt.",
    "Connection Settings" : "Savienojuma iestatījumi",
    "Configuration Active" : "Konfigurācija ir aktīva",
    "When unchecked, this configuration will be skipped." : "Ja nav atzīmēts, šī konfigurācija tiks izlaista.",
    "Backup (Replica) Host" : "Rezerves (kopija) serveris",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "Norādi rezerves serveri (nav obligāti). Tam ir jābūt galvenā LDAP/AD servera kopijai.",
    "Backup (Replica) Port" : "Rezerves (kopijas) ports",
    "Disable Main Server" : "Deaktivēt galveno serveri",
    "Turn off SSL certificate validation." : "Izslēgt SSL sertifikātu validēšanu.",
    "Cache Time-To-Live" : "Kešatmiņas dzīvlaiks",
    "in seconds. A change empties the cache." : "sekundēs. Izmaiņas iztukšos kešatmiņu.",
    "Directory Settings" : "Direktorijas iestatījumi",
    "User Display Name Field" : "Lietotāja redzamā vārda lauks",
    "Base User Tree" : "Bāzes lietotāju koks",
    "One User Base DN per line" : "Viens lietotājs bāzes DN rindā",
    "User Search Attributes" : "Lietotāju meklēšanas atribūts",
    "Optional; one attribute per line" : "Neobligāti; viens atribūts rindā",
    "Group Display Name Field" : "Grupas redzamā nosaukuma lauks",
    "Base Group Tree" : "Bāzes grupu koks",
    "One Group Base DN per line" : "Viena grupu bāzes DN rindā",
    "Group Search Attributes" : "Grupu meklēšanas atribūts",
    "Group-Member association" : "Grupu piederības asociācija",
    "Enable LDAP password changes per user" : "Iespējot LDAP paroles maiņu katram lietotājam",
    "(New password is sent as plain text to LDAP)" : "(Jaunā parole tiek nosūtīta kā vienkāršs teksts ar LDAP)",
    "Special Attributes" : "Īpašie atribūti",
    "Quota Field" : "Kvotu lauks",
    "Quota Default" : "Kvotas noklusējums",
    "Email Field" : "E-pasta lauks",
    "User Home Folder Naming Rule" : "Lietotāja mājas mapes nosaukšanas kārtula",
    "Internal Username" : "Iekšējais lietotājvārds",
    "Override UUID detection" : "Ignorēt UUID noteikšanu",
    "UUID Attribute for Users:" : "UUID atribūti lietotājiem:",
    "UUID Attribute for Groups:" : "UUID atribūti grupām:",
    "LDAP / AD integration" : "LDAP / AD integrācija",
    "LDAP / AD Username:" : "LDAP / AD lietotājvārds:",
    "LDAP / AD Email Address:" : "LDAP / AD e-pasta adrese:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
